@@ -140,7 +140,8 @@ namespace Oxygen
         _backgroundHintHook.connect( "realize", (GSignalEmissionHook)backgroundHintHook, this );
 
         #if ENABLE_INNER_SHADOWS_HACK
-        _innerShadowHook.connect( "realize", (GSignalEmissionHook)innerShadowHook, this );
+        if(!getenv("OXYGEN_DISABLE_INNER_SHADOWS_HACK"))
+            _innerShadowHook.connect( "realize", (GSignalEmissionHook)innerShadowHook, this );
         #endif
 
         _sizeAllocationHook.connect( "size-allocate", (GSignalEmissionHook)sizeAllocationHook, this );
@@ -231,6 +232,22 @@ namespace Oxygen
             return TRUE;
         }
 
+        #if GTK_CHECK_VERSION( 3, 5, 0 )
+        /*
+        HACK: Somehow, style_updated method for GtkRange widgets is not called anymore
+        as soon as we (oxygen-gtk) install our hooks. This prevents some settings to be
+        properly initialized, such as the slider length, or the arrows for scrollbars.
+        Therefore we explicitly call the styleUpdated function ourselves.
+        */
+        if( GTK_IS_RANGE( widget ) )
+        {
+            // get class
+            GtkWidgetClass* widgetClass = GTK_WIDGET_GET_CLASS( widget );
+            if( widgetClass && widgetClass->style_updated )
+            { (*widgetClass->style_updated)(widget); }
+        }
+        #endif
+
         // groupbox labels
         #if ENABLE_GROUPBOX_HACK
         if( static_cast<Animations*>( data )->groupBoxLabelEngine().contains( widget ) )
@@ -276,26 +293,28 @@ namespace Oxygen
             << std::endl;
         #endif
 
+        int uglyShadowWidth=!Gtk::gdk_default_screen_is_composited();
+
         // perform move-resize
         if( widthChanged && positionChanged )
         {
 
             gdk_window_move_resize(
                 gtk_widget_get_window( widget ),
-                targetX + comboAllocation.x + 3, sourceY,
-                comboAllocation.width - 6, widgetAllocation.height );
+                targetX + comboAllocation.x + 3 - uglyShadowWidth, sourceY,
+                comboAllocation.width - 6 + 2*uglyShadowWidth, widgetAllocation.height );
 
         } else if( widthChanged ) {
 
             gdk_window_resize(
                 gtk_widget_get_window( widget ),
-                comboAllocation.width - 6, widgetAllocation.height );
+                comboAllocation.width - 6 + 2*uglyShadowWidth, widgetAllocation.height );
 
         } else if( positionChanged ) {
 
             gdk_window_move(
                 gtk_widget_get_window( widget ),
-                targetX + comboAllocation.x + 3, sourceY );
+                targetX + comboAllocation.x + 3 - uglyShadowWidth, sourceY );
 
         }
 
@@ -335,7 +354,6 @@ namespace Oxygen
         Animations& animations( *static_cast<Animations*>(data) );
         if( !animations.innerShadowsEnabled() ) return TRUE;
 
-        if( Gtk::gtk_combobox_is_tree_view( widget ) ) return TRUE;
         if( Gtk::g_object_is_a( G_OBJECT( widget ), "SwtFixed" ) ) return TRUE;
 
         GtkWidget* parent(gtk_widget_get_parent(widget));
